Statistics package
==================

**The module offers methods such as:**

    - callrate calculation for SNP data. The call rate for a given SNP is defined as the proportion of individuals in the study for which the corresponding SNP information is not missing.
    - calculation of the frequency of the occurrence of alleles.
    - the Hardy-Weinberg equilibrium (HWE) is a principle stating that the genetic variation in a population will remain constant from one generation to the next in the absence of disturbing factors.

.. automodule:: snplib.statistics
   :members:
   :undoc-members:
   :show-inheritance:
